from typing import List, Optional

from pydantic import BaseModel, EmailStr


class FileAttachment(BaseModel):
    file_name: str
    url: str
    file_id: Optional[str] = None


class SendMailRequest(BaseModel):
    to: List[EmailStr]
    subject: str
    body: str
    from_email: Optional[EmailStr] = None
    cc: List[EmailStr] = []
    bcc: List[EmailStr] = []
