from abs_email_core.provider.base import EmailProvider

__all__ = ["EmailProvider", "SendGridProvider"]


def __getattr__(name):
    if name == "SendGridProvider":
        from abs_email_core.provider.sendgrid_provider import SendGridProvider

        return SendGridProvider
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
